@@ -30,8 +30,9 @@ import cairo
 import gi
 gi.require_version('GstTag', '1.0')
 gi.require_version('MediaArt', '2.0')
+gi.require_version("Soup", "2.4")
 from gi.repository import (Gdk, GdkPixbuf, Gio, GLib, GObject, Gtk, MediaArt,
-                           Gst, GstTag, GstPbutils)
+                           Gst, GstTag, GstPbutils, Soup)
 
 from gnomemusic.musiclogger import MusicLogger
 
@@ -546,7 +547,8 @@ class RemoteArt(GObject.GObject):
         self._artist = None
         self._album = None
         self._coresong = None
-        self._grilo = None
+        self._coregrilo = None
+        self._soup_session = Soup.Session.new()
 
     def query(self, coresong):
         """Start the remote query
@@ -563,27 +565,24 @@ class RemoteArt(GObject.GObject):
 
         self.emit('no-remote-sources')
 
-        # FIXME: This is a total hack. It gets CoreModel from the
-        # CoreAlbum or CoreSong about and then retrieves the CoreGrilo
-        # instance.
-        try:
-            self._grilo = self._coresong._coremodel.props.grilo
-        except AttributeError:
-            self._grilo = self._coresong._grilo
+        # FIXME: This is a hack. It gets CoreGrilo from the CoreAlbum
+        # or CoreSong private instance.
+        self._coregrilo = self._coresong._coregrilo
 
-        if not self._grilo.props.cover_sources:
+        if not self._coregrilo.props.cover_sources:
             self.emit('no-remote-sources')
-            self._grilo.connect(
-                'notify::cover-sources', self._on_grilo_cover_sources_changed)
+            self._coregrilo.connect(
+                "notify::cover-sources",
+                self._on_coregrilo_cover_sources_changed)
         else:
             # FIXME: It seems this Grilo query does not always return,
             # especially on queries with little info.
-            self._grilo.get_album_art_for_item(
+            self._coregrilo.get_album_art_for_item(
                 self._coresong, self._remote_album_art)
 
-    def _on_grilo_cover_sources_changed(self, klass, data):
-        if self._grilo.props.cover_sources:
-            self._grilo.get_album_art_for_item(
+    def _on_coregrilo_cover_sources_changed(self, klass, data):
+        if self._coregrilo.props.cover_sources:
+            self._coregrilo.get_album_art_for_item(
                 self._coresong, self._remote_album_art)
 
     def _delete_callback(self, src, result, data):
@@ -636,8 +635,15 @@ class RemoteArt(GObject.GObject):
                 "Error: {}, {}".format(error.domain, error.message))
 
     def _read_callback(self, src, result, data):
+        if result.props.status_code != 200:
+            self._log.debug(
+                "Failed to get remote art for the album {} by {} : {}".format(
+                    self._album, self._artist, result.props.reason_phrase))
+            return
+
         try:
-            istream = src.read_finish(result)
+            istream = Gio.MemoryInputStream.new_from_bytes(
+                result.props.response_body_data)
         except GLib.Error as error:
             self._log.warning(
                 "Error: {}, {}".format(error.domain, error.message))
@@ -673,6 +679,5 @@ class RemoteArt(GObject.GObject):
             self.emit('unavailable')
             return
 
-        src = Gio.File.new_for_uri(thumb_uri)
-        src.read_async(
-            GLib.PRIORITY_LOW, None, self._read_callback, None)
+        msg = Soup.Message.new("GET", thumb_uri)
+        self._soup_session.queue_message(msg, self._read_callback, None)
