@@ -61,26 +61,20 @@ class GrlTrackerWrapper(GObject.GObject):
         Grl.METADATA_KEY_THUMBNAIL,
     ]
 
-    def __init__(
-            self, source, coremodel, application, grilo, tracker_wrapper):
+    def __init__(self, source, application, tracker_wrapper):
         """Initialize the Tracker wrapper
 
         :param Grl.TrackerSource source: The Tracker source to wrap
-        :param CoreModel coremodel: CoreModel instance to use models
-        from
         :param Application application: Application instance
-        :param CoreGrilo grilo: The CoreGrilo instance
         :param TrackerWrapper tracker_wrapper: The TrackerWrapper instance
         """
         super().__init__()
 
         self._application = application
-        self._coremodel = coremodel
-        self._coreselection = application.props.coreselection
-        self._grilo = grilo
-        self._source = None
+        self._coremodel = application.props.coremodel
         self._log = application.props.log
-        self._model = self._coremodel.props.songs
+        self._songs_model = self._coremodel.props.songs
+        self._source = None
         self._albums_model = self._coremodel.props.albums
         self._album_ids = {}
         self._artists_model = self._coremodel.props.artists
@@ -95,7 +89,7 @@ class GrlTrackerWrapper(GObject.GObject):
         self._tracker_wrapper = tracker_wrapper
         self._window = application.props.window
 
-        self._song_search_tracker = Gfm.FilterListModel.new(self._model)
+        self._song_search_tracker = Gfm.FilterListModel.new(self._songs_model)
         self._song_search_tracker.set_filter_func(lambda a: False)
         self._song_search_proxy.append(self._song_search_tracker)
 
@@ -224,7 +218,7 @@ class GrlTrackerWrapper(GObject.GObject):
             if media.get_id() in self._album_ids.keys():
                 album = self._album_ids[media.get_id()]
             else:
-                album = CoreAlbum(media, self._coremodel)
+                album = CoreAlbum(self._application, media)
 
             album_ids[media.get_id()] = album
 
@@ -284,7 +278,7 @@ class GrlTrackerWrapper(GObject.GObject):
             if media.get_id() in self._artist_ids.keys():
                 artist = self._artist_ids[media.get_id()]
             else:
-                artist = CoreArtist(media, self._coremodel)
+                artist = CoreArtist(self._application, media)
 
             artist_ids[media.get_id()] = artist
 
@@ -301,12 +295,12 @@ class GrlTrackerWrapper(GObject.GObject):
                 self._log.warning("Removal KeyError.")
                 return
 
-            for idx, coresong_model in enumerate(self._model):
+            for idx, coresong_model in enumerate(self._songs_model):
                 if coresong_model is coresong:
                     self._log.debug("Removing: {}, {}".format(
                         coresong.props.media.get_id(), coresong.props.title))
 
-                    self._model.remove(idx)
+                    self._songs_model.remove(idx)
                     break
 
     def _song_media_query(self, media_ids):
@@ -355,17 +349,17 @@ class GrlTrackerWrapper(GObject.GObject):
                 self._remove_media(media_ids)
                 return
 
-            if media.get_id() not in self._hash:
+            media_id = media.get_id()
+            if media_id not in self._hash:
+                song = CoreSong(self._application, media)
+                self._songs_model.append(song)
+                self._hash[media_id] = song
                 self._log.debug(
-                    "Media {} not in hash".format(media.get_id()))
-
-                song = CoreSong(media, self._coreselection, self._grilo)
-                self._model.append(song)
-                self._hash[media.get_id()] = song
+                    "Adding: {}, {}".format(media_id, song.props.title))
             else:
-                self._hash[media.get_id()].update(media)
+                self._hash[media_id].update(media)
 
-            media_ids.remove(media.get_id())
+            media_ids.remove(media_id)
 
         options = self._fast_options.copy()
 
@@ -384,23 +378,25 @@ class GrlTrackerWrapper(GObject.GObject):
                 return
 
             if not media:
-                self._model.splice(self._model.get_n_items(), 0, songs_added)
+                self._songs_model.splice(
+                    self._songs_model.get_n_items(), 0, songs_added)
                 self._window.notifications_popup.pop_loading()
 
                 # Initialize the playlists subwrapper after the initial
                 # songs model fill, the playlists expect a filled songs
                 # hashtable.
                 self._tracker_playlists = GrlTrackerPlaylists(
-                    self.props.source, self._coremodel, self._application,
-                    self._grilo, self._tracker_wrapper, self._hash)
+                    self.props.source, self._application,
+                    self._tracker_wrapper, self._hash)
 
                 return
 
-            song = CoreSong(media, self._coreselection, self._grilo)
+            song = CoreSong(self._application, media)
             songs_added.append(song)
             self._hash[media.get_id()] = song
             if len(songs_added) == self._SPLICE_SIZE:
-                self._model.splice(self._model.get_n_items(), 0, songs_added)
+                self._songs_model.splice(
+                    self._songs_model.get_n_items(), 0, songs_added)
                 songs_added.clear()
 
         query = """
@@ -452,7 +448,7 @@ class GrlTrackerWrapper(GObject.GObject):
                 self._window.notifications_popup.pop_loading()
                 return
 
-            album = CoreAlbum(media, self._coremodel)
+            album = CoreAlbum(self._application, media)
             self._album_ids[media.get_id()] = album
             albums_added.append(album)
             if len(albums_added) == self._SPLICE_SIZE:
@@ -506,7 +502,7 @@ class GrlTrackerWrapper(GObject.GObject):
                 self._window.notifications_popup.pop_loading()
                 return
 
-            artist = CoreArtist(media, self._coremodel)
+            artist = CoreArtist(self._application, media)
             self._artist_ids[media.get_id()] = artist
             artists_added.append(artist)
             if len(artists_added) == self._SPLICE_SIZE:
@@ -637,7 +633,7 @@ class GrlTrackerWrapper(GObject.GObject):
                 return
 
             disc_nr = media.get_album_disc_number()
-            coredisc = CoreDisc(media, disc_nr, self._coremodel)
+            coredisc = CoreDisc(self._application, media, disc_nr)
             disc_model.append(coredisc)
 
         options = self._fast_options.copy()
@@ -706,13 +702,19 @@ class GrlTrackerWrapper(GObject.GObject):
         query = """
         SELECT DISTINCT
             rdf:type(?artist)
-            tracker:id(?artist) AS ?id
+            COALESCE(tracker:id(?album_artist), tracker:id(?artist)) AS ?id
         WHERE {
             ?song a nmm:MusicPiece ;
                     nmm:musicAlbum ?album ;
                     nmm:performer ?artist .
-            BIND(tracker:normalize(
-                nmm:artistName(nmm:albumArtist(?album)), 'nfkd') AS ?match1) .
+            OPTIONAL {
+                ?album a nmm:MusicAlbum ;
+                         nmm:albumArtist ?album_artist .
+            }
+            BIND(COALESCE(nmm:artistName(?album_artist),
+                          nmm:artistName(?artist)) AS ?artist_bind)
+            BIND(tracker:normalize(nmm:artistName(
+                nmm:albumArtist(?artist_bind)), 'nfkd') AS ?match1) .
             BIND(tracker:normalize(
                 nmm:artistName(nmm:performer(?song)), 'nfkd') AS ?match2) .
             BIND(tracker:normalize(nmm:composer(?song), 'nfkd') AS ?match4) .
