@@ -277,7 +277,7 @@ class MPRIS(DBusInterface):
     _playlist_nb_songs = 10
 
     def __init__(self, app):
-        name = 'org.mpris.MediaPlayer2.GnomeMusic'
+        name = "org.mpris.MediaPlayer2.{}".format(app.props.application_id)
         path = '/org/mpris/MediaPlayer2'
         super().__init__(name, path, app)
 
@@ -418,9 +418,6 @@ class MPRIS(DBusInterface):
         return path
 
     def _update_tracklist(self):
-        # FIXME: On a repeat-mode change, the current song needs to be queried
-        # to update the player position property.
-        self._player.props.current_song
         previous_path_list = self._path_list
         self._path_list = []
         self._metadata_list = []
@@ -731,11 +728,10 @@ class MPRIS(DBusInterface):
         :param str path: Identifier of the track to skip to
         """
         current_index = self._path_list.index(self._get_song_dbus_path())
-        current_coresong = self._player.props.current_song
+        current_coresong = self._player_model[current_index]
 
         goto_index = self._path_list.index(path)
-        new_position = self._player.props.position + goto_index - current_index
-        new_coresong = self._player_model[new_position]
+        new_coresong = self._player_model[goto_index]
 
         self._player.play(new_coresong)
         current_coresong.props.state = SongWidget.State.PLAYED
