@@ -31,6 +31,11 @@ from gnomemusic.widgets.songwidget import SongWidget
 
 @Gtk.Template(resource_path='/org/gnome/Music/ui/ArtistAlbumWidget.ui')
 class ArtistAlbumWidget(Gtk.Box):
+    """"Widget containing one album by an artist
+
+    The album cover and some information on one side and a
+    DiscListBox (list of all discs of the album) on the other side.
+    """
 
     __gtype_name__ = 'ArtistAlbumWidget'
 
@@ -47,23 +52,23 @@ class ArtistAlbumWidget(Gtk.Box):
         ),
     }
 
-    def __init__(
-            self, corealbum, selection_mode_allowed, size_group=None,
-            cover_size_group=None):
+    def __init__(self, corealbum, size_group=None, cover_size_group=None):
+        """Initialize the ArtistAlbumWidget
+
+        :param CoreAlbum corealbum: The CoreAlbum object
+        :param GtkSizeGroup size_group: SizeGroup for the discs
+        :param GtkSizeGroup cover_size_group: SizeGroup for the cover
+        """
         super().__init__(orientation=Gtk.Orientation.HORIZONTAL)
 
         self._size_group = size_group
         self._cover_size_group = cover_size_group
 
         self._selection_mode = False
-        self._selection_mode_allowed = selection_mode_allowed
 
         self._cover_stack.props.size = Art.Size.MEDIUM
         self._cover_stack.update(corealbum)
 
-        allowed = self._selection_mode_allowed
-        self._disc_list_box.props.selection_mode_allowed = allowed
-
         self.bind_property(
             'selection-mode', self._disc_list_box, 'selection-mode',
             GObject.BindingFlags.BIDIRECTIONAL
@@ -88,12 +93,8 @@ class ArtistAlbumWidget(Gtk.Box):
         corealbum.props.model.items_changed(0, 0, 0)
 
     def _create_widget(self, disc):
-        disc_box = self._create_disc_box(disc.props.disc_nr, disc.model)
-
-        self._disc_list_box.bind_property(
-            "selection-mode-allowed", disc_box, "selection-mode-allowed",
-            GObject.BindingFlags.BIDIRECTIONAL
-            | GObject.BindingFlags.SYNC_CREATE)
+        disc_box = DiscBox(disc)
+        disc_box.connect('song-activated', self._song_activated)
 
         self._disc_list_box.bind_property(
             "selection-mode", disc_box, "selection-mode",
@@ -102,16 +103,6 @@ class ArtistAlbumWidget(Gtk.Box):
 
         return disc_box
 
-    def _create_disc_box(self, disc_nr, album_model):
-        disc_box = DiscBox(album_model)
-        disc_box.set_disc_number(disc_nr)
-        disc_box.props.show_durations = True
-        disc_box.props.show_favorites = True
-        disc_box.props.show_song_numbers = True
-        disc_box.connect('song-activated', self._song_activated)
-
-        return disc_box
-
     def _on_model_items_changed(self, model, position, removed, added):
         n_items = model.get_n_items()
         for i in range(n_items):
