@@ -58,7 +58,7 @@ class SearchHeaderBar(Gtk.HeaderBar):
     def __init__(self, application):
         super().__init__()
 
-        self._application = application
+        self._coregrilo = application.props.coregrilo
         self._selection_mode = False
         self._timeout = None
 
@@ -88,10 +88,6 @@ class SearchHeaderBar(Gtk.HeaderBar):
             "search-mode-active", self._search_button, "active",
             GObject.BindingFlags.BIDIRECTIONAL
             | GObject.BindingFlags.SYNC_CREATE)
-        self.bind_property(
-            "selection-mode", self._search_button, "visible",
-            GObject.BindingFlags.INVERT_BOOLEAN
-            | GObject.BindingFlags.SYNC_CREATE)
 
         self.connect(
             "notify::selection-mode-allowed",
@@ -189,7 +185,7 @@ class SearchHeaderBar(Gtk.HeaderBar):
         search_term = self._entry.get_text()
         if search_term != "":
             self.props.stack.set_visible_child_name("search")
-            self._application.props.coremodel.search(search_term)
+            self._coregrilo.search(search_term)
         else:
             self._set_error_style(False)
 
