@@ -58,8 +58,6 @@ class SongWidget(Gtk.EventBox):
     coresong = GObject.Property(type=CoreSong, default=None)
     select_click = GObject.Property(type=bool, default=False)
     selected = GObject.Property(type=bool, default=False)
-    show_duration = GObject.Property(type=bool, default=True)
-    show_favorite = GObject.Property(type=bool, default=True)
     show_song_number = GObject.Property(type=bool, default=True)
 
     _album_label = Gtk.Template.Child()
@@ -124,19 +122,11 @@ class SongWidget(Gtk.EventBox):
 
         self._play_icon.set_from_icon_name(
             'media-playback-start-symbolic', Gtk.IconSize.SMALL_TOOLBAR)
-        self._play_icon.set_no_show_all(True)
 
         self.props.coresong.bind_property(
             'selected', self._select_button, 'active',
             GObject.BindingFlags.BIDIRECTIONAL
             | GObject.BindingFlags.SYNC_CREATE)
-        self.bind_property(
-            'show-duration', self._duration_label, 'visible',
-            GObject.BindingFlags.SYNC_CREATE)
-        self._duration_label.set_no_show_all(True)
-        self.bind_property(
-            'show-favorite', self._star_eventbox, 'visible',
-            GObject.BindingFlags.SYNC_CREATE)
         self.bind_property(
             'show-song-number', self._number_label, 'visible',
             GObject.BindingFlags.SYNC_CREATE)
@@ -153,8 +143,6 @@ class SongWidget(Gtk.EventBox):
         if not self.props.coresong.props.is_tracker:
             self._star_stack.props.visible_child_name = "empty"
 
-        self._number_label.props.no_show_all = True
-
         if can_dnd is True:
             self._dnd_eventbox.props.visible = True
             self._drag_widget = None
@@ -184,7 +172,7 @@ class SongWidget(Gtk.EventBox):
         drag_row = SongWidget(self.props.coresong)
         self._drag_widget.add(drag_row)
         self._drag_widget.drag_highlight_row(drag_row.get_parent())
-        self._drag_widget.show_all()
+        self._drag_widget.props.visible = True
         Gtk.drag_set_icon_widget(context, self._drag_widget, x, y)
 
     @Gtk.Template.Callback()
